==> down.php?SDK=HIVE_SDK_Android_v4.15.6.1_withCore.zip: Sample/app/src/main/java/com/hive/sample/SocialV4TestView.kt <==
package com.hive.sample

import android.app.Activity
import android.view.View
import android.widget.ArrayAdapter
import android.widget.EditText
import android.widget.Spinner
import com.com2us.hivesdk.normal.freefull.google.global.android.common.R
import com.hive.Configuration
import com.hive.ResultAPI
import com.hive.SocialV4
import com.hive.sample.uihelper.ViewPagerBase

class SocialV4TestView(activity: Activity, view: View, title: String) : ViewPagerBase(activity, view, title), View.OnClickListener {

    init {
        initUi()
    }

    private fun initUi() {
        createLogView(R.id.logview, R.id.btnLogDialog, R.id.btnLogClear)

        val spAdapter: ArrayAdapter<CharSequence> = ArrayAdapter(activity, android.R.layout.simple_spinner_item)
        spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
        SocialV4.ProviderType.values().forEach { providerType ->
            spAdapter.add(providerType.name)
        }

        val spinner: Spinner = this.view.findViewById<View>(R.id.spProviderType) as Spinner
        spinner.adapter = spAdapter

        this.view.findViewById<View>(R.id.btnShowCommunity).setOnClickListener(this)
        this.view.findViewById<View>(R.id.btnSharePhoto).setOnClickListener(this)

    }

    override fun onClick(v: View) {

        when (v.id) {
            R.id.btnShowCommunity -> {
                val providerType = getSelectedProviderType()

                SocialV4.showCommunity(providerType, object : SocialV4.SocialV4ShowCommunityListener {
                    override fun onShowCommunity(result: ResultAPI) {
                        addLog("\n\n=== SocialV4 커뮤니티 호출 ===\n")
                        addLog("\n\n=== SocialV4.showCommunity($providerType) ===\n")
                        addLog("\n\n=== result: $result ===\n")
                    }
                })
            }

            R.id.btnSharePhoto -> {
                val providerType = getSelectedProviderType()

                SocialV4.sharePhoto(providerType, object : SocialV4.SocialV4SharePhotoListener {
                    override fun onShare(result: ResultAPI) {
                        addLog("\n\n=== SocialV4 사진 공유 호출 ===\n")
                        addLog("\n\n=== SocialV4.sharePhoto($providerType) ===\n")
                        addLog("\n\n=== result: $result ===\n")
                    }
                })

            }
        }
    }

    private fun getSelectedProviderType(): SocialV4.ProviderType {
        val spinner: Spinner = this.view.findViewById(R.id.spProviderType) as Spinner
        val providerTypeName = spinner.adapter.getItem(spinner.selectedItemPosition) as String
        return SocialV4.ProviderType.valueOf(providerTypeName)
    }
}

==> down.php?SDK=HIVE_SDK_Android_v4.15.8.5_withCore.zip: Sample/app/src/main/java/com/hive/sample/SocialV4TestView.kt <==
package com.hive.sample

import android.app.Activity
import android.view.View
import android.widget.ArrayAdapter
import android.widget.Spinner
import com.com2us.hivesdk.normal.freefull.google.global.android.common.R
import com.hive.ResultAPI
import com.hive.SocialV4
import com.hive.sample.uihelper.ViewPagerBase

class SocialV4TestView(activity: Activity, view: View, title: String) : ViewPagerBase(activity, view, title), View.OnClickListener {

    init {
        initUi()
    }

    private fun initUi() {
        createLogView(R.id.logview, R.id.btnLogDialog, R.id.btnLogClear)

        val spAdapter: ArrayAdapter<CharSequence> = ArrayAdapter(activity, android.R.layout.simple_spinner_item)
        spAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
        SocialV4.ProviderType.values().forEach { providerType ->
            spAdapter.add(providerType.name)
        }

        val spinner: Spinner = this.view.findViewById<View>(R.id.spProviderType) as Spinner
        spinner.adapter = spAdapter

        this.view.findViewById<View>(R.id.btnShowCommunity).setOnClickListener(this)
        this.view.findViewById<View>(R.id.btnSharePhoto).setOnClickListener(this)

    }

    override fun onClick(v: View) {

        when (v.id) {
            R.id.btnShowCommunity -> {
                val providerType = getSelectedProviderType()
                val viewType = SocialV4.ViewType.Frame

                SocialV4.showCommunity(providerType, viewType, object : SocialV4.SocialV4ShowCommunityListener {
                    override fun onShowCommunity(result: ResultAPI) {
                        addLog("\n\n=== SocialV4 커뮤니티 호출 ===\n")
                        addLog("\n\n=== SocialV4.showCommunity($providerType, $viewType) ===\n")
                        addLog("\n\n=== result: $result ===\n")
                    }
                })
            }

            R.id.btnSharePhoto -> {
                val providerType = getSelectedProviderType()

                SocialV4.sharePhoto(providerType, object : SocialV4.SocialV4SharePhotoListener {
                    override fun onShare(result: ResultAPI) {
                        addLog("\n\n=== SocialV4 사진 공유 호출 ===\n")
                        addLog("\n\n=== SocialV4.sharePhoto($providerType) ===\n")
                        addLog("\n\n=== result: $result ===\n")
                    }
                })

            }
        }
    }

    private fun getSelectedProviderType(): SocialV4.ProviderType {
        val spinner: Spinner = this.view.findViewById(R.id.spProviderType) as Spinner
        val providerTypeName = spinner.adapter.getItem(spinner.selectedItemPosition) as String
        return SocialV4.ProviderType.valueOf(providerTypeName)
    }
}
